jaclearn.dataflow.collections
=============================

.. automodule:: jaclearn.dataflow.collections

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DictDataFlowProxy
      DictToBatchDataFlow
      EmptyDictDataFlow
      KVStoreDataFlow
      KVStoreRandomSampleDataFlow
      LOARandomSampleDataFlow
      ListOfArrayDataFlow
      PoolDataFlow
      PoolRandomSampleDataFlow
      QueueDataFlow
      RandomIndexDataFlow
      RandomRepeatDataFlow
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      DOARandomSampleDataFlow
      DictOfArrayDataFlow
   
   

   
   
   








.. rubric:: Class DictDataFlowProxy
.. autoclass:: DictDataFlowProxy
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DictToBatchDataFlow
.. autoclass:: DictToBatchDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class EmptyDictDataFlow
.. autoclass:: EmptyDictDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class KVStoreDataFlow
.. autoclass:: KVStoreDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class KVStoreRandomSampleDataFlow
.. autoclass:: KVStoreRandomSampleDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LOARandomSampleDataFlow
.. autoclass:: LOARandomSampleDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ListOfArrayDataFlow
.. autoclass:: ListOfArrayDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class PoolDataFlow
.. autoclass:: PoolDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class PoolRandomSampleDataFlow
.. autoclass:: PoolRandomSampleDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class QueueDataFlow
.. autoclass:: QueueDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomIndexDataFlow
.. autoclass:: RandomIndexDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class RandomRepeatDataFlow
.. autoclass:: RandomRepeatDataFlow
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: DOARandomSampleDataFlow

.. autofunction:: DictOfArrayDataFlow


